@@ -24,6 +24,7 @@
 #include "ksudoku_version.h"
 
 #include <KAboutData>
+#include <KDBusService>
 #include <KCrash>
 #include <KLocalizedString>
 #include <KConfigDialogManager>
@@ -39,7 +40,8 @@
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-	KLocalizedString::setApplicationDomain("ksudoku");
+
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("ksudoku"));
 
 	KAboutData about(QStringLiteral("ksudoku"),
                      i18n("KSudoku"),
@@ -68,6 +70,8 @@ int main(int argc, char **argv)
 
 	KCrash::initialize();
 
+	KDBusService service;
+
 	// see if we are starting with session management
 	/*if (app.isRestored())
 	{
